.. meta::
   :description: Reference documentation for general PyTorch utilities provided by the rAI-toolbox

.. _pytorch-utils:

#################
General Utilities
#################


*****************
PyTorch Utilities
*****************

We provide general, PyTorch-centric utilities that help to reduce boilerplate code and to ensure
correctness when using the rAI-toolbox.

.. currentmodule:: rai_toolbox

.. autosummary::
   :toctree: generated/

   to_batch
   evaluating
   freeze
   frozen
   negate